<%@ Page Language="C#" Debug="true" %>
<%@ Import Namespace="ChartDirector" %>
<%@ Register TagPrefix="chart" Namespace="ChartDirector" Assembly="netchartdir" %>

<!DOCTYPE html>

<script runat="server">

//
// Page Load event handler
//
protected void Page_Load(object sender, EventArgs e)
{
    // The x-axis and y-axis labels
    string[] xLabels = {"A", "B", "C", "D", "E", "F", "G", "H", "I", "J"};
    string[] yLabels = {"0", "1", "2", "3", "4", "5", "6", "7", "8", "9"};

    // Random data for the 10 x 10 cells
    RanSeries r = new RanSeries(2);
    double[] zData = r.get2DSeries(xLabels.Length, yLabels.Length, 0, 100);

    // Create an XYChart object of size 520 x 470 pixels.
    XYChart c = new XYChart(520, 470);

    // Set the plotarea at (50, 30) and of size 400 x 400 pixels.
    PlotArea p = c.setPlotArea(50, 30, 400, 400);

    // Create a discrete heat map with 10 x 10 cells
    DiscreteHeatMapLayer layer = c.addDiscreteHeatMapLayer(zData, xLabels.Length);

    // Set the x-axis labels. Use 8pt Arial Bold font. Set axis stem to transparent, so only the
    // labels are visible. Set 0.5 offset to position the labels in between the grid lines.
    c.xAxis().setLabels(xLabels);
    c.xAxis().setLabelStyle("Arial Bold", 8);
    c.xAxis().setColors(Chart.Transparent, Chart.TextColor);
    c.xAxis().setLabelOffset(0.5);
    c.xAxis().setTitle("X Axis Title Placeholder", "Arial Bold", 12);

    // Set the y-axis labels. Use 8pt Arial Bold font. Set axis stem to transparent, so only the
    // labels are visible. Set 0.5 offset to position the labels in between the grid lines.
    c.yAxis().setLabels(yLabels);
    c.yAxis().setLabelStyle("Arial Bold", 8);
    c.yAxis().setColors(Chart.Transparent, Chart.TextColor);
    c.yAxis().setLabelOffset(0.5);
    c.yAxis().setTitle("Y Axis Title Placeholder", "Arial Bold", 12);

    // Position the color axis 20 pixels to the right of the plot area and of the same height as the
    // plot area. Put the labels on the right side of the color axis. Use 8pt Arial Bold font for
    // the labels.
    ColorAxis cAxis = layer.setColorAxis(p.getRightX() + 20, p.getTopY(), Chart.TopLeft,
        p.getHeight(), Chart.Right);
    cAxis.setLabelStyle("Arial Bold", 8);

    // Output the chart
    WebChartViewer1.Image = c.makeWebImage(Chart.SVG);

    // Include tool tip for the chart
    WebChartViewer1.ImageMap = c.getHTMLImageMap("", "",
        "title='<*cdml*>({xLabel}, {yLabel}) = {z|2}'");
}

</script>

<html>
<head>
    <title>Discrete Heat Map</title>
    <script type="text/javascript" src="cdjcv.js"></script>
</head>
<body style="margin:5px 0px 0px 5px">
    <div style="font:bold 18pt verdana">
        Discrete Heat Map
    </div>
    <hr style="border:solid 1px #000080; background:#000080" />
    <div style="font:10pt verdana; margin-bottom:1.5em">
        <a href='viewsource.aspx?file=<%=Request["SCRIPT_NAME"]%>'>View Source Code</a>
    </div>
    <chart:WebChartViewer id="WebChartViewer1" runat="server" />
</body>
</html>

