using System;
using System.Windows.Forms;

namespace CSharpChartExplorer
{
	/// <summary>
	/// Application to demonstrate using ChartDirector
	/// </summary>
	public partial class ChartExplorer : Form
	{
		//
		// Array to hold all Windows.ChartViewers in the form to allow processing using loops
		//
		private ChartDirector.WinChartViewer[] chartViewers;
		
		//
		// Data structure to handle the Back / Forward buttons. We support up to
		// 100 histories. We store histories as the nodes begin selected.
		//
		private TreeNode[] history = new TreeNode[100];
		
		// The array index of the currently selected node in the history array.
		private int currentHistoryIndex = -1;

		// The array index of the last valid entry in the history array so that we
		// know if we can use the Forward button.
		private int lastHistoryIndex = -1;

		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main() 
		{
			Application.Run(new ChartExplorer());			
		}

		/// <summary>
		/// ChartExplorer Constructor
		/// </summary>
		public ChartExplorer()
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			//
			// Array to hold all Windows.ChartViewers in the form to allow processing 
			// using loops
			//
			chartViewers = new ChartDirector.WinChartViewer[] 
			{ 
				chartViewer1, chartViewer2, chartViewer3, chartViewer4, 
				chartViewer5, chartViewer6, chartViewer7, chartViewer8
			};

			//
			// Build the tree view on the left to represent available demo modules
			//
			TreeNode pieNode = new TreeNode("Pie Charts", 2, 2);
			treeView.Nodes.Add(pieNode);

			pieNode.Nodes.Add(MakeNode(new simplepie(), 2));
			pieNode.Nodes.Add(MakeNode(new threedpie(), 2));
			pieNode.Nodes.Add(MakeNode(new multidepthpie(), 2));
			pieNode.Nodes.Add(MakeNode(new sidelabelpie(), 2));
			pieNode.Nodes.Add(MakeNode(new circlelabelpie(), 2));
			pieNode.Nodes.Add(MakeNode(new legendpie(), 2));
			pieNode.Nodes.Add(MakeNode(new legendpie2(), 2));
			pieNode.Nodes.Add(MakeNode(new explodedpie(), 2));
			pieNode.Nodes.Add(MakeNode(new iconpie(), 2));
			pieNode.Nodes.Add(MakeNode(new iconpie2(), 2));
			pieNode.Nodes.Add(MakeNode(new multipie(), 2));
			pieNode.Nodes.Add(MakeNode(new donut(), 2));
			pieNode.Nodes.Add(MakeNode(new threeddonut(), 2));
			pieNode.Nodes.Add(MakeNode(new icondonut(), 2));
			pieNode.Nodes.Add(MakeNode(new texturedonut(), 2));
			pieNode.Nodes.Add(MakeNode(new concentric(), 2));
			pieNode.Nodes.Add(MakeNode(new pieshading(), 2));
			pieNode.Nodes.Add(MakeNode(new threedpieshading(), 2));
			pieNode.Nodes.Add(MakeNode(new donutshading(), 2));
			pieNode.Nodes.Add(MakeNode(new threeddonutshading(), 2));
			pieNode.Nodes.Add(MakeNode(new fontpie(), 2));
			pieNode.Nodes.Add(MakeNode(new threedanglepie(), 2));
			pieNode.Nodes.Add(MakeNode(new threeddepthpie(), 2));
			pieNode.Nodes.Add(MakeNode(new shadowpie(), 2));
			pieNode.Nodes.Add(MakeNode(new anglepie(), 2));
			pieNode.Nodes.Add(MakeNode(new donutwidth(), 2));

			TreeNode barNode = new TreeNode("Bar Charts", 3, 3);
			treeView.Nodes.Add(barNode);

			barNode.Nodes.Add(MakeNode(new simplebar(), 3));
            barNode.Nodes.Add(MakeNode(new simplebar2(), 3));
            barNode.Nodes.Add(MakeNode(new barlabel(), 3)); 
            barNode.Nodes.Add(MakeNode(new colorbar(), 3));
            barNode.Nodes.Add(MakeNode(new colorbar2(), 3));
            barNode.Nodes.Add(MakeNode(new softlightbar(), 3));
			barNode.Nodes.Add(MakeNode(new glasslightbar(), 3));
			barNode.Nodes.Add(MakeNode(new gradientbar(), 3));
			barNode.Nodes.Add(MakeNode(new cylinderlightbar(), 3));
			barNode.Nodes.Add(MakeNode(new threedbar(), 3));
			barNode.Nodes.Add(MakeNode(new cylinderbar(), 3));
			barNode.Nodes.Add(MakeNode(new polygonbar(), 3));
			barNode.Nodes.Add(MakeNode(new stackedbar(), 3));
			barNode.Nodes.Add(MakeNode(new percentbar(), 3));
			barNode.Nodes.Add(MakeNode(new multibar(), 3));
			barNode.Nodes.Add(MakeNode(new softmultibar(), 3));
			barNode.Nodes.Add(MakeNode(new glassmultibar(), 3));
			barNode.Nodes.Add(MakeNode(new gradientmultibar(), 3));
			barNode.Nodes.Add(MakeNode(new multicylinder(), 3));
			barNode.Nodes.Add(MakeNode(new multishapebar(), 3));
			barNode.Nodes.Add(MakeNode(new overlapbar(), 3));
			barNode.Nodes.Add(MakeNode(new multistackbar(), 3));
			barNode.Nodes.Add(MakeNode(new depthbar(), 3));
			barNode.Nodes.Add(MakeNode(new posnegbar(), 3));
			barNode.Nodes.Add(MakeNode(new hbar(), 3));
			barNode.Nodes.Add(MakeNode(new dualhbar(), 3));
			barNode.Nodes.Add(MakeNode(new markbar(), 3));
			barNode.Nodes.Add(MakeNode(new pareto(), 3));
			barNode.Nodes.Add(MakeNode(new varwidthbar(), 3));
			barNode.Nodes.Add(MakeNode(new gapbar(), 3));

			TreeNode lineNode = new TreeNode("Line Charts", 4, 4);
			treeView.Nodes.Add(lineNode);

			lineNode.Nodes.Add(MakeNode(new simpleline(), 4));
			lineNode.Nodes.Add(MakeNode(new compactline(), 4));
			lineNode.Nodes.Add(MakeNode(new threedline(), 4));
			lineNode.Nodes.Add(MakeNode(new multiline(), 4));
            lineNode.Nodes.Add(MakeNode(new multiline2(), 4));
			lineNode.Nodes.Add(MakeNode(new multicolorline(), 4));
            lineNode.Nodes.Add(MakeNode(new symbolline(), 4));
			lineNode.Nodes.Add(MakeNode(new symbolline2(), 4));
			lineNode.Nodes.Add(MakeNode(new missingpoints(), 4));
			lineNode.Nodes.Add(MakeNode(new unevenpoints(), 4));
			lineNode.Nodes.Add(MakeNode(new splineline(), 4));
			lineNode.Nodes.Add(MakeNode(new stepline(), 4));
			lineNode.Nodes.Add(MakeNode(new linefill(), 4));
			lineNode.Nodes.Add(MakeNode(new linecompare(), 4));
			lineNode.Nodes.Add(MakeNode(new errline(), 4));
			lineNode.Nodes.Add(MakeNode(new multisymbolline(), 4));
			lineNode.Nodes.Add(MakeNode(new binaryseries(), 4));
			lineNode.Nodes.Add(MakeNode(new customsymbolline(), 4));
			lineNode.Nodes.Add(MakeNode(new rotatedline(), 4));
			lineNode.Nodes.Add(MakeNode(new xyline(), 4));
			
			TreeNode trendNode = new TreeNode("Trending and Curve Fitting", 5, 5);
			treeView.Nodes.Add(trendNode);

			trendNode.Nodes.Add(MakeNode(new trendline(), 5));
			trendNode.Nodes.Add(MakeNode(new scattertrend(), 5));
			trendNode.Nodes.Add(MakeNode(new confidenceband(), 5));
			trendNode.Nodes.Add(MakeNode(new paramcurve(), 5));
			trendNode.Nodes.Add(MakeNode(new curvefitting(), 5));
			
			TreeNode scatterNode = new TreeNode("Scatter/Bubble/Vector Charts", 6, 6);
			treeView.Nodes.Add(scatterNode);

			scatterNode.Nodes.Add(MakeNode(new scatter(), 6));
			scatterNode.Nodes.Add(MakeNode(new builtinsymbols(), 6));
			scatterNode.Nodes.Add(MakeNode(new scattersymbols(), 6));
			scatterNode.Nodes.Add(MakeNode(new scatterlabels(), 6));
			scatterNode.Nodes.Add(MakeNode(new bubble(), 6));
			scatterNode.Nodes.Add(MakeNode(new threedbubble(), 6));
			scatterNode.Nodes.Add(MakeNode(new threedbubble2(), 6));
			scatterNode.Nodes.Add(MakeNode(new threedbubble3(), 6));
			scatterNode.Nodes.Add(MakeNode(new bubblescale(), 6));
			scatterNode.Nodes.Add(MakeNode(new vector(), 6));

			TreeNode areaNode = new TreeNode("Area Charts", 7, 7);
			treeView.Nodes.Add(areaNode);

			areaNode.Nodes.Add(MakeNode(new simplearea(), 7));
			areaNode.Nodes.Add(MakeNode(new enhancedarea(), 7));
            areaNode.Nodes.Add(MakeNode(new arealine(), 7));
            areaNode.Nodes.Add(MakeNode(new threedarea(), 7));
			areaNode.Nodes.Add(MakeNode(new patternarea(), 7));
			areaNode.Nodes.Add(MakeNode(new stackedarea(), 7));
			areaNode.Nodes.Add(MakeNode(new threedstackarea(), 7));
			areaNode.Nodes.Add(MakeNode(new percentarea(), 7));
			areaNode.Nodes.Add(MakeNode(new deptharea(), 7));
			areaNode.Nodes.Add(MakeNode(new rotatedarea(), 7));

			TreeNode boxNode = new TreeNode("Floating Box/Waterfall Charts", 8, 8);
			treeView.Nodes.Add(boxNode);

			boxNode.Nodes.Add(MakeNode(new boxwhisker(), 8));
			boxNode.Nodes.Add(MakeNode(new boxwhisker2(), 8));
            boxNode.Nodes.Add(MakeNode(new hboxwhisker(), 8));
            boxNode.Nodes.Add(MakeNode(new floatingbox(), 8));
			boxNode.Nodes.Add(MakeNode(new waterfall(), 8));
			boxNode.Nodes.Add(MakeNode(new posnegwaterfall(), 8));

			TreeNode ganttNode = new TreeNode("Gantt Charts", 9, 9);
			treeView.Nodes.Add(ganttNode);

			ganttNode.Nodes.Add(MakeNode(new gantt(), 9));
			ganttNode.Nodes.Add(MakeNode(new colorgantt(), 9));
			ganttNode.Nodes.Add(MakeNode(new layergantt(), 9));

			TreeNode contourNode = new TreeNode("Contour Charts/Heat Maps", 10, 10);
			treeView.Nodes.Add(contourNode);
			
			contourNode.Nodes.Add(MakeNode(new contour(), 10));
            contourNode.Nodes.Add(MakeNode(new scattercontour(), 10));
            contourNode.Nodes.Add(MakeNode(new contourcolor(), 10));
            contourNode.Nodes.Add(MakeNode(new contourlegend(), 10));
            contourNode.Nodes.Add(MakeNode(new smoothcontour(), 10));
			contourNode.Nodes.Add(MakeNode(new contourinterpolate(), 10));
			contourNode.Nodes.Add(MakeNode(new contourcrosssection(), 10));

			TreeNode discreteHeatMapNode = new TreeNode("Discrete Heat Maps", 11, 11);
			treeView.Nodes.Add(discreteHeatMapNode);

			discreteHeatMapNode.Nodes.Add(MakeNode(new discreteheatmap(), 11));
			discreteHeatMapNode.Nodes.Add(MakeNode(new wafermap(), 11));
			discreteHeatMapNode.Nodes.Add(MakeNode(new heatmapcelllabels(), 11));
			discreteHeatMapNode.Nodes.Add(MakeNode(new heatmapcellsymbols(), 11));

			TreeNode financeNode = new TreeNode("Finance Charts", 12, 12);
			treeView.Nodes.Add(financeNode);

			financeNode.Nodes.Add(MakeNode(new hloc(), 12));
			financeNode.Nodes.Add(MakeNode(new candlestick(), 12));
			financeNode.Nodes.Add(MakeNode(new finance(), 12));
			financeNode.Nodes.Add(MakeNode(new finance2(), 12));
            financeNode.Nodes.Add(MakeNode(new financesymbols(), 12));
            financeNode.Nodes.Add(MakeNode(new financedemo(), 12));
			
			TreeNode xyMiscNode = new TreeNode("Other XY Chart Features", 13, 13);
			treeView.Nodes.Add(xyMiscNode);

			xyMiscNode.Nodes.Add(MakeNode(new markzone(), 13));
			xyMiscNode.Nodes.Add(MakeNode(new markzone2(), 13));
			xyMiscNode.Nodes.Add(MakeNode(new yzonecolor(), 13));
			xyMiscNode.Nodes.Add(MakeNode(new xzonecolor(), 13));
			xyMiscNode.Nodes.Add(MakeNode(new dualyaxis(), 13));
			xyMiscNode.Nodes.Add(MakeNode(new dualxaxis(), 13));
			xyMiscNode.Nodes.Add(MakeNode(new multiaxes(), 13));
			xyMiscNode.Nodes.Add(MakeNode(new fourq(), 13));
			xyMiscNode.Nodes.Add(MakeNode(new datatable(), 13));
			xyMiscNode.Nodes.Add(MakeNode(new datatable2(), 13));
			xyMiscNode.Nodes.Add(MakeNode(new fontxy(), 13));
			xyMiscNode.Nodes.Add(MakeNode(new background(), 13));
			xyMiscNode.Nodes.Add(MakeNode(new logaxis(), 13));
			xyMiscNode.Nodes.Add(MakeNode(new axisscale(), 13));
			xyMiscNode.Nodes.Add(MakeNode(new ticks(), 13));
			xyMiscNode.Nodes.Add(MakeNode(new cdmltooltip(), 13));
			
			TreeNode surfaceNode = new TreeNode("Surface Charts", 14, 14);
			treeView.Nodes.Add(surfaceNode);

			surfaceNode.Nodes.Add(MakeNode(new surface(), 14));
			surfaceNode.Nodes.Add(MakeNode(new surface2(), 14));
			surfaceNode.Nodes.Add(MakeNode(new surface3(), 14));
			surfaceNode.Nodes.Add(MakeNode(new surface4d(), 14));
			surfaceNode.Nodes.Add(MakeNode(new scattersurface(), 14));
			surfaceNode.Nodes.Add(MakeNode(new surfaceaxis(), 14));
			surfaceNode.Nodes.Add(MakeNode(new surfacecolor(), 14));
			surfaceNode.Nodes.Add(MakeNode(new surfacelighting(), 14));
			surfaceNode.Nodes.Add(MakeNode(new surfaceshading(), 14));
			surfaceNode.Nodes.Add(MakeNode(new surfacewireframe(), 14));
			surfaceNode.Nodes.Add(MakeNode(new surfaceperspective(), 14));
			surfaceNode.Nodes.Add(MakeNode(new surfaceprojection(), 14));
			surfaceNode.Nodes.Add(MakeNode(new surfacelinezone(), 14));
			surfaceNode.Nodes.Add(MakeNode(new surfacetexture(), 14));
			surfaceNode.Nodes.Add(MakeNode(new threedchartrotation(), 14));

			TreeNode threeDScatterNode = new TreeNode("3D Scatter Charts", 15, 15);
            treeView.Nodes.Add(threeDScatterNode);

            threeDScatterNode.Nodes.Add(MakeNode(new threedscatter(), 15));
            threeDScatterNode.Nodes.Add(MakeNode(new threedscatter2(), 15));
            threeDScatterNode.Nodes.Add(MakeNode(new threedscattergroups(), 15));
            threeDScatterNode.Nodes.Add(MakeNode(new threedscatteraxis(), 15));

			TreeNode polarNode = new TreeNode("Polar Charts", 16, 16);
			treeView.Nodes.Add(polarNode);

			polarNode.Nodes.Add(MakeNode(new simpleradar(), 16));
			polarNode.Nodes.Add(MakeNode(new multiradar(), 16));
			polarNode.Nodes.Add(MakeNode(new stackradar(), 16));
			polarNode.Nodes.Add(MakeNode(new polarline(), 16));
			polarNode.Nodes.Add(MakeNode(new polararea(), 16));
			polarNode.Nodes.Add(MakeNode(new polarspline(), 16));
			polarNode.Nodes.Add(MakeNode(new polarscatter(), 16));
			polarNode.Nodes.Add(MakeNode(new polarbubble(), 16));
			polarNode.Nodes.Add(MakeNode(new polarvector(), 16));
			polarNode.Nodes.Add(MakeNode(new rose(), 16));
			polarNode.Nodes.Add(MakeNode(new stackrose(), 16));
			polarNode.Nodes.Add(MakeNode(new polarzones(), 16));
			polarNode.Nodes.Add(MakeNode(new polarzones2(), 16));

			TreeNode treeMapNode = new TreeNode("Tree Map Charts", 17, 17);
			treeView.Nodes.Add(treeMapNode);

			treeMapNode.Nodes.Add(MakeNode(new simpletreemap(), 17));
			treeMapNode.Nodes.Add(MakeNode(new multileveltreemap(), 17));
			treeMapNode.Nodes.Add(MakeNode(new treemapcolors(), 17));
			treeMapNode.Nodes.Add(MakeNode(new treemaplayout(), 17));
			treeMapNode.Nodes.Add(MakeNode(new multileveltreemaplayout(), 17));

			TreeNode pyramidNode = new TreeNode("Pyramids/Cones/Funnels", 18, 18);
			treeView.Nodes.Add(pyramidNode);
			
			pyramidNode.Nodes.Add(MakeNode(new simplepyramid(), 18));
			pyramidNode.Nodes.Add(MakeNode(new threedpyramid(), 18));
			pyramidNode.Nodes.Add(MakeNode(new rotatedpyramid(), 18));
			pyramidNode.Nodes.Add(MakeNode(new cone(), 18));
			pyramidNode.Nodes.Add(MakeNode(new funnel(), 18));
			pyramidNode.Nodes.Add(MakeNode(new pyramidelevation(), 18));
			pyramidNode.Nodes.Add(MakeNode(new pyramidrotation(), 18));
			pyramidNode.Nodes.Add(MakeNode(new pyramidgap(), 18));
										   
			TreeNode angularMeterNode = new TreeNode("Angular Meters/Gauges", 19, 19);
            treeView.Nodes.Add(angularMeterNode);

            angularMeterNode.Nodes.Add(MakeNode(new semicirclemeter(), 19));
            angularMeterNode.Nodes.Add(MakeNode(new colorsemicirclemeter(), 19));
            angularMeterNode.Nodes.Add(MakeNode(new blacksemicirclemeter(), 19));
            angularMeterNode.Nodes.Add(MakeNode(new whitesemicirclemeter(), 19));
            angularMeterNode.Nodes.Add(MakeNode(new semicirclemeterreadout(), 19));
            angularMeterNode.Nodes.Add(MakeNode(new roundmeter(), 19));
            angularMeterNode.Nodes.Add(MakeNode(new colorroundmeter(), 19));
            angularMeterNode.Nodes.Add(MakeNode(new blackroundmeter(), 19));
            angularMeterNode.Nodes.Add(MakeNode(new whiteroundmeter(), 19));
            angularMeterNode.Nodes.Add(MakeNode(new neonroundmeter(), 19));
            angularMeterNode.Nodes.Add(MakeNode(new roundmeterreadout(), 19));
            angularMeterNode.Nodes.Add(MakeNode(new rectangularmeter(), 19));
            angularMeterNode.Nodes.Add(MakeNode(new squareameter(), 19));
            angularMeterNode.Nodes.Add(MakeNode(new angularpointer(), 19));
            angularMeterNode.Nodes.Add(MakeNode(new angularpointer2(), 19));
            angularMeterNode.Nodes.Add(MakeNode(new iconameter(), 19));
			angularMeterNode.Nodes.Add(MakeNode(new circularbarmeter(), 19));
			angularMeterNode.Nodes.Add(MakeNode(new circularbarmeter2(), 19));

			TreeNode linearMeterNode = new TreeNode("Linear Meters/Gauges", 20, 20);
            treeView.Nodes.Add(linearMeterNode);

            linearMeterNode.Nodes.Add(MakeNode(new hlinearmeter(), 20));
            linearMeterNode.Nodes.Add(MakeNode(new colorhlinearmeter(), 20));
            linearMeterNode.Nodes.Add(MakeNode(new blackhlinearmeter(), 20));
            linearMeterNode.Nodes.Add(MakeNode(new whitehlinearmeter(), 20));
            linearMeterNode.Nodes.Add(MakeNode(new hlinearmeterorientation(), 20));
            linearMeterNode.Nodes.Add(MakeNode(new vlinearmeter(), 20));
            linearMeterNode.Nodes.Add(MakeNode(new colorvlinearmeter(), 20));
            linearMeterNode.Nodes.Add(MakeNode(new blackvlinearmeter(), 20));
            linearMeterNode.Nodes.Add(MakeNode(new whitevlinearmeter(), 20));
            linearMeterNode.Nodes.Add(MakeNode(new vlinearmeterorientation(), 20));
            linearMeterNode.Nodes.Add(MakeNode(new multihmeter(), 20));
            linearMeterNode.Nodes.Add(MakeNode(new multivmeter(), 20));
            linearMeterNode.Nodes.Add(MakeNode(new linearzonemeter(), 20));

			TreeNode barMeterNode = new TreeNode("Bar Meters/Gauges", 21, 21);
            treeView.Nodes.Add(barMeterNode);

            barMeterNode.Nodes.Add(MakeNode(new hbarmeter(), 21));
            barMeterNode.Nodes.Add(MakeNode(new colorhbarmeter(), 21));
            barMeterNode.Nodes.Add(MakeNode(new blackhbarmeter(), 21));
            barMeterNode.Nodes.Add(MakeNode(new whitehbarmeter(), 21));
            barMeterNode.Nodes.Add(MakeNode(new hbarmeterorientation(), 21));
            barMeterNode.Nodes.Add(MakeNode(new vbarmeter(), 21));
            barMeterNode.Nodes.Add(MakeNode(new colorvbarmeter(), 21));
            barMeterNode.Nodes.Add(MakeNode(new blackvbarmeter(), 21));
            barMeterNode.Nodes.Add(MakeNode(new whitevbarmeter(), 21));
            barMeterNode.Nodes.Add(MakeNode(new vbarmeterorientation(), 21));

            TreeNode trackCursorNode = new TreeNode("Programmable Track Cursor", 22, 22);
            treeView.Nodes.Add(trackCursorNode);

            trackCursorNode.Nodes.Add(MakeNode(new tracklegend(), 22));
            trackCursorNode.Nodes.Add(MakeNode(new tracklabel(), 22));
            trackCursorNode.Nodes.Add(MakeNode(new trackaxis(), 22));
            trackCursorNode.Nodes.Add(MakeNode(new trackbox(), 22));
            trackCursorNode.Nodes.Add(MakeNode(new trackfinance(), 22));
            trackCursorNode.Nodes.Add(MakeNode(new crosshair(), 22));

			TreeNode zoomScrollNode = new TreeNode("Zooming and Scrolling", 23, 23);
            treeView.Nodes.Add(zoomScrollNode);

            zoomScrollNode.Nodes.Add(MakeNode(new simplezoomscroll(), 23));
            zoomScrollNode.Nodes.Add(MakeNode(new zoomscrolltrack(), 23));
            zoomScrollNode.Nodes.Add(MakeNode(new zoomscrolltrack2(), 23));
			zoomScrollNode.Nodes.Add(MakeNode(new zoomscrollpdf(), 23));
			zoomScrollNode.Nodes.Add(MakeNode(new megazoomscroll(), 23));
            zoomScrollNode.Nodes.Add(MakeNode(new viewportcontroldemo(), 23));
            zoomScrollNode.Nodes.Add(MakeNode(new xyzoomscroll(), 23));
			zoomScrollNode.Nodes.Add(MakeNode(new contourzoomscroll(), 23));

			TreeNode realTimeNode = new TreeNode("Real Time Charts", 24, 24);
			treeView.Nodes.Add(realTimeNode);

			realTimeNode.Nodes.Add(MakeNode(new realtimedemo(), 24));
            realTimeNode.Nodes.Add(MakeNode(new realtimetrack(), 24));
            realTimeNode.Nodes.Add(MakeNode(new realtimezoomscroll(), 24));
			realTimeNode.Nodes.Add(MakeNode(new megarealtimezoomscroll(), 24));
			realTimeNode.Nodes.Add(MakeNode(new realtimemultichart(), 24));
		}

		/// <summary>
		/// Help method to add a demo module to the tree
		/// </summary>
		private TreeNode MakeNode(DemoModule module, int icon)
		{
			TreeNode node = new TreeNode(module.getName(), icon, icon);
			node.Tag = module;	// The demo module is attached to the node as the Tag property.
			return node;
		}
		
		/// <summary>
		/// Handler for the TreeView AfterSelect event
		/// </summary>
		private void treeView_AfterSelect(object sender, System.Windows.Forms.TreeViewEventArgs e)
		{
			// Check if a demo module node is selected. Demo module is attached to the node
			// as the Tag property
			DemoModule demo = (DemoModule)e.Node.Tag;
			if (demo != null)
			{
				// Display the title
				title.Text = demo.getName();

				// Clear all ChartViewers
				for (int i = 0; i < chartViewers.Length; ++i)
					chartViewers[i].Visible = false;

				// Each demo module can display a number of charts
				int noOfCharts = demo.getNoOfCharts();
				for (int i = 0; i < noOfCharts; ++i)
				{
					demo.createChart(chartViewers[i], i);
					chartViewers[i].Visible = true;
				}
						
				// Now perform flow layout of the charts (viewers) 
				layoutCharts();

				// Add current node to the history array to support Back/Forward browsing
				addHistory(e.Node);
			}

			// Update the state of the buttons, status bar, etc.
			updateControls();
		}

		/// <summary>
		/// Helper method to perform a flow layout (left to right, top to bottom) of
		/// the chart.
		/// </summary>
		private void layoutCharts()
		{
			// Margin between the charts
			int margin = 5;

			// The first chart is always at the position as seen on the visual designer
			ChartDirector.WinChartViewer viewer =  chartViewers[0];
			viewer.Top = line.Bottom + margin;

			// The next chart is at the left of the first chart
			int currentX = viewer.Left + viewer.Width + margin;
			int currentY = viewer.Top;

			// The line height of a line of charts is that of the tallest chart in the line
			int lineHeight = viewer.Height;
			
			// Now layout subsequent charts (other than the first chart)
			for (int i = 1; i < chartViewers.Length; ++i)
			{
				viewer = chartViewers[i];
				
				// Layout only visible charts
				if (!viewer.Visible)
					continue;

				// Check for enough space on the left before it hits the panel border
				if (currentX + viewer.Width > rightPanel.Width)
				{
					// Not enough space, so move to the next line

					// Start of line is to align with the left of the first chart
					currentX = chartViewers[0].Left;

					// Adjust vertical by lineHeight plus a margin
					currentY += lineHeight + margin;

					// Reset the lineHeight
					lineHeight = 0;
				}
				
				// Put the chart at the current position
				viewer.Left = currentX;
				viewer.Top = currentY;

				// Advance the current position to the left prepare for the next chart
				currentX += viewer.Width + margin;

				// Update the lineHeight to reflect the tallest chart so far encountered
				// in the same line
				if (lineHeight < viewer.Height)
					lineHeight = viewer.Height;
			}
		}

		/// <summary>
		/// Add a selected node to the history array
		/// </summary>
		private void addHistory(TreeNode node)
		{
			// Don't add if selected node is current node to avoid duplication.
			if ((currentHistoryIndex >= 0) && (node == history[currentHistoryIndex]))
				return;

			// Check if the history array is full
			if (currentHistoryIndex + 1 >= history.Length)
			{
				// History array is full. Remove oldest 25% from the history array.
				// We add 1 to make sure at least 1 item is removed.
				int itemsToDiscard = history.Length / 4 + 1;

				// Remove the oldest items by shifting the array. 
				for (int i = itemsToDiscard; i < history.Length; ++i)
					history[i - itemsToDiscard] = history[i];
				
				// Adjust index because array is shifted.
				currentHistoryIndex = history.Length - itemsToDiscard;
			}
			
			// Add node to history array
			history[++currentHistoryIndex] = node;

			// After adding a new node, the forward button is always disabled. (This
			// is consistent with normal browser behaviour.) That means the last 
			// history node is always assumed to be the current node. 
			lastHistoryIndex = currentHistoryIndex;
		}

		/// <summary>
		/// Handlers for the ToolStrip Button Click event
		/// </summary>
		private void backButton_Click(object sender, EventArgs e)
		{
			backHistory();
		}
		private void forwardButton_Click(object sender, EventArgs e)
		{
			forwardHistory();
		}
		private void previousButton_Click(object sender, EventArgs e)
		{
			prevNode();
		}
		private void nextButton_Click(object sender, EventArgs e)
		{
			nextNode();
		}
		private void viewCodeButton_Click(object sender, EventArgs e)
		{
			viewSource();
		}
		private void viewDocButton_Click(object sender, EventArgs e)
		{
			help();
		}

		/// <summary>
		/// Handler for the Back button
		/// </summary>
		private void backHistory()
		{
			// Select the previous node in the history array
			if (currentHistoryIndex > 0)
				treeView.SelectedNode = history[--currentHistoryIndex];
		}

		/// <summary>
		/// Handler for the Forward button
		/// </summary>
		private void forwardHistory()
		{
			// Select the next node in the history array
			if (lastHistoryIndex > currentHistoryIndex)
				treeView.SelectedNode = history[++currentHistoryIndex];
		}

		/// <summary>
		/// Handler for the Next button
		/// </summary>
		private void nextNode()
		{
			// Getnext chart node of the current selected node by going down the tree
			TreeNode node = getNextChartNode(treeView.SelectedNode);
			
			// Display the node if available
			if (node != null)
				treeView.SelectedNode = node;
		}
		
		/// <summary>
		/// Helper method to go to the next chart node down the tree
		/// </summary>
		private TreeNode getNextChartNode(TreeNode node)
		{
			// Get the next node of by going down the tree
			node = getNextNode(node);
			
			// Skip nodes that are not associated with charts (e.g the folder nodes)
			while ((node != null) && (node.Tag == null))
				node = getNextNode(node);

			return node;
		}
			
		/// <summary>
		/// Helper method to go to the next node down the tree
		/// </summary>
		private TreeNode getNextNode(TreeNode node)
		{
			if (node == null)
				return null;
			
			// If the current node is a folder, the next node is the first child.
			if (node.FirstNode != null)
				return node.FirstNode;
			
			while (node != null)
			{
				// If there is a next sibling node, it is the next node.
				if (node.NextNode != null)
					return node.NextNode;

				// If there is no sibling node, the next node is the next sibling 
				// of the parent node. So we go back to the parent and loop again.
				node = node.Parent;
			}

			// No next node - must be already the last node.
            return null;
		}

		/// <summary>
		/// Handler for the Previous button
		/// </summary>
		private void prevNode()
		{
			// Get previous chart node of the current selected node by going up the tree
			TreeNode node = getPrevChartNode(treeView.SelectedNode);

			// Display the node if available
			if (node != null)
				treeView.SelectedNode = node;
		}
		
		/// <summary>
		/// Helper method to go to the previous chart node down the tree
		/// </summary>
		private TreeNode getPrevChartNode(TreeNode node)
		{
			// Get the prev node of by going up the tree
			node = getPrevNode(node);
			
			// Skip nodes that are not associated with charts (e.g the folder nodes)
			while ((node != null) && (node.Tag == null))
				node = getPrevNode(node);

			return node;
		}
		
		/// <summary>
		/// Helper method to go to the previous node up the tree
		/// </summary>
		private TreeNode getPrevNode(TreeNode node)
		{
			if (node == null)
				return null;
			
			// If there is no previous sibling node, the previous node must be its
			// parent. 
			if (node.PrevNode == null)
				return node.Parent;
		
			// If there is a previous sibling node, the previous node is the last
			// child of the previous sibling (if it has any child at all).
			node = node.PrevNode;
			while (node.LastNode != null)
				node = node.LastNode;

			return node;
		}

		/// <summary>
		/// Handler for the View Source button
		/// </summary>
		private void viewSource()
		{
			// Get the path name of the help file
			string helpFilePath = getHelpPath();
			if ((helpFilePath != null) && (currentHistoryIndex >= 0))
			{
                DemoModule m = (DemoModule)(history[currentHistoryIndex].Tag);
				Help.ShowHelp(this, helpFilePath, HelpNavigator.Topic, m.GetType().Name + ".htm");
			}
		}

		/// <summary>
		/// Handler for the View Doc button
		/// </summary>
		private void help()
		{
			// Get the path name of the help file
			string helpFilePath = getHelpPath();
			if (helpFilePath != null)
				Help.ShowHelp(this, helpFilePath);
		}

		/// <summary>
		/// Helper method to get the path name of the help file
		/// </summary>
		private string getHelpPath()
		{
			string helpfile = "netchartdir.chm";

			// We search various places for the help file.
			string[] placeToSearch = new string[]
			{
				"",					// the current folder
				"../../../../doc/",	// the doc folder relative to the "Debug" folder
				"../../../../../doc/",
				"../../",			// the project or solution folder relative to "Debug")
				"../../../",
				"../../../../"
			};

			// Return the first directory that contains the help file
			for (int i = 0; i < placeToSearch.Length; ++i)
			{
				if (System.IO.File.Exists(placeToSearch[i] + helpfile))
					return placeToSearch[i] + helpfile;
			}

			// Help file not found ???
			MessageBox.Show("Cannot locate help file " + helpfile + ".", "Help Error",
				MessageBoxButtons.OK, MessageBoxIcon.Error);

			return null;
		}

		/// <summary>
		/// Helper method to update the various controls
		/// </summary>
		private void updateControls()
		{
			//
			// Enable the various buttons there is really something they can do.
			//
			backButton.Enabled = (currentHistoryIndex > 0);
			forwardButton.Enabled = (lastHistoryIndex > currentHistoryIndex);
			nextButton.Enabled = (getNextChartNode(treeView.SelectedNode) != null);
			previousButton.Enabled = (getPrevChartNode(treeView.SelectedNode) != null);
		}

		/// <summary>
		/// Handler for the panel layout event
		/// </summary>
		private void rightPanel_Layout(object sender, System.Windows.Forms.LayoutEventArgs e)
		{
			// Perform flow layout of the charts 
			if (chartViewers != null)
				layoutCharts();
		}

		/// <summary>
		/// Handler for the ClickHotSpot event, which occurs when the mouse clicks on 
		/// a hot spot on the chart
		/// </summary>
		private void chartViewer_ClickHotSpot(object sender, ChartDirector.WinHotSpotEventArgs e)
		{
			// In this demo, just list out the information provided by ChartDirector about hot spot
			new ParamViewer().Display(sender, e);
		}
	}
}
