Imports System
Imports Microsoft.VisualBasic
Imports ChartDirector

Public Class circularbarmeter
    Implements DemoModule

    'Name of demo module
    Public Function getName() As String Implements DemoModule.getName
        Return "Circular Bar Meters"
    End Function

    'Number of charts produced in this demo module
    Public Function getNoOfCharts() As Integer Implements DemoModule.getNoOfCharts
        Return 8
    End Function

    'Main code for creating charts
    Public Sub createChart(viewer As WinChartViewer, chartIndex As Integer) _
        Implements DemoModule.createChart

        ' The value to display on the meter
        Dim value As Double = 77

        ' The meter radius and angle
        Dim radius As Integer = 50
        Dim angle As Double = value * 360.0 / 100

        ' Create an AngularMeter with transparent background
        Dim m As AngularMeter = New AngularMeter(radius * 2 + 10, radius * 2 + 10, _
            Chart.Transparent)

        ' Set the center, radius and angular range of the meter
        m.setMeter(m.getWidth() \ 2, m.getHeight() \ 2, radius, 0, 360)

        ' For circular bar meters, we do not need pointer or graduation, so we hide them.
        m.setMeterColors(Chart.Transparent, Chart.Transparent, Chart.Transparent)
        m.setCap(0, Chart.Transparent)

        '
        ' This example demonstrates several coloring styles
        '

        ' Thd default fill and blank colors
        Dim fillColor As Integer = &H6699ff
        Dim blankColor As Integer = &Heeeeee

        If chartIndex >= 4 Then
            ' Use dark background style
            m.setColors(Chart.whiteOnBlackPalette)
            blankColor = &H222222
        End If

        If chartIndex Mod 4 = 1 Then
            ' Alternative fill color
            fillColor = &Hff6600
        ElseIf chartIndex Mod 4 = 2 Then
            ' Use a smooth color scale as the fill color
            Dim smoothColorScale() As Integer = {0, &H0022ff, 15, &H0088ff, 30, &H00ff00, 55, _
                &Hffff00, 80, &Hff0000, 100, &Hff0000}
            fillColor = m.getDrawArea().angleGradientColor(m.getWidth() \ 2, m.getHeight() \ 2, 0, _
                360, radius, radius - 20, smoothColorScale)
        ElseIf chartIndex Mod 4 = 3 Then
            ' Use a step color scale as the fill color
            Dim stepColorScale() As Integer = {0, &H0044ff, 20, &H00ee00, 50, &Heeee00, 70, _
                &Hee0000, 100}
            fillColor = m.getDrawArea().angleGradientColor(m.getWidth() \ 2, m.getHeight() \ 2, 0, _
                360, radius, radius - 20, stepColorScale)
        End If

        ' Draw the blank part of the circular bar
        If angle < 360 Then
            m.addRingSector(radius, radius - 20, angle, 360, blankColor)
        End If

        ' Draw the fill part of the circular bar
        If angle > 0 Then
            m.addRingSector(radius, radius - 20, 0, angle, fillColor)
        End If

        ' Add a label at the center to display the value
        m.addText(m.getWidth() \ 2, m.getHeight() \ 2, m.formatValue(value, "{value}"), "Arial", _
            25, Chart.TextColor, Chart.Center).setMargin(0)

        ' Output the chart
        viewer.Chart = m

    End Sub

End Class

