﻿Imports ChartDirector

Public Class FrmContourCrossSection

	Private contourLayer As ContourLayer

	' Keep track of mouse dragging state
	Private Enum DragState
		None
		Horizontal
		Vertical
	End Enum
	Private isDragging As DragState = DragState.None
	Private dragOffset As Integer = 0

	' Crosshair position
	Private crossHairX As Integer = 300
	Private crossHairY As Integer = 300

	Private Sub FrmContourPlotCrossSection_Load(sender As Object, e As EventArgs) Handles MyBase.Load
		drawChart(winChartViewer1)

		' Extended the plot area mouse event region to make it easier to drag the crosshair
		winChartViewer1.setPlotAreaMouseMargin(100)
	End Sub

	'
	' Draw the main chart
	'
	Private Sub drawChart(viewer As WinChartViewer)

		' The x And y coordinates of the grid
		Dim dataX() As Double = {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10}
		Dim dataY() As Double = {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10}
		Dim dataZ(dataX.Length * dataY.Length - 1) As Double

		' Pseudo-random data for he z-coordinates
		For iY As Integer = 0 To dataY.Length - 1
			Dim y As Double = dataY(iY)
			Dim ay As Double = 11 * Math.Cos(iY * Math.PI * 2 / (dataY.Length - 1) + 1.1673)
			For iX As Integer = 0 To dataX.Length - 1
				Dim x As Double = dataX(iX)
				Dim ax As Double = 11 * Math.Cos(iX * Math.PI * 2 / (dataX.Length - 1) + 0.8629)
				dataZ(iY * dataX.Length + iX) =
					20 + ((ax + 0.43) * Math.Sin(y) + (ay + 0.9166) * Math.Sin(x) + 0.0998) *
					Math.Sin((1 + Math.Abs(x) / 10.0) * (1 + Math.Abs(y) / 10.0) * 0.6667)
			Next
		Next

		' Create a XYChart object of size 575 x 525 pixels
		Dim c As XYChart = New XYChart(575, 525)

		' Set the plotarea at (75, 30) And of size 450 x 450 pixels. Use semi-transparent black
		' (80000000) dotted lines for both horizontal And vertical grid lines
		Dim p As PlotArea = c.setPlotArea(75, 30, 450, 450, -1, -1, -1, c.dashLineColor(
				&HAF000000, Chart.DotLine), -1)

		' Set the chart And axis titles
		c.addTitle("     <*block,bgcolor=FFFF00*> *** Drag Crosshair to Move Cross Section *** <*/*>",
			"Arial Bold", 15)
		c.xAxis().setTitle("X-Axis Title Place Holder", "Arial Bold Italic", 10)
		c.yAxis().setTitle("Y-Axis Title Place Holder", "Arial Bold Italic", 10)

		' Put the y-axis on the right side of the chart
		c.setYAxisOnRight()

		' Set x-axis And y-axis labels to use Arial Bold font
		c.xAxis().setLabelStyle("Arial", 10)
		c.yAxis().setLabelStyle("Arial", 10)

		' When auto-scaling, use tick spacing of 40 pixels as a guideline
		c.yAxis().setTickDensity(40)
		c.xAxis().setTickDensity(40)

		' Add a contour layer using the given data
		contourLayer = c.addContourLayer(dataX, dataY, dataZ)
		contourLayer.setContourLabelFormat("<*font=Arial Bold,size=10*>{value}<*/font*>")

		' Move the grid lines in front of the contour layer
		c.getPlotArea().moveGridBefore(contourLayer)

		' Add a vertical color axis at x = 0 at the same y-position as the plot area.
		Dim cAxis As ColorAxis = contourLayer.setColorAxis(0, p.getTopY(), Chart.TopLeft,
				p.getHeight(), Chart.Right)
		' Use continuous gradient coloring (as opposed to step colors)
		cAxis.setColorGradient(True)

		' Add a title to the color axis using 12 points Arial Bold Italic font
		cAxis.setTitle("Color Legend Title Place Holder", "Arial Bold Italic", 10)

		' Set color axis labels to use Arial Bold font
		cAxis.setLabelStyle("Arial", 10)

		' Set the chart image to the WinChartViewer
		viewer.Chart = c

		' Tooltip for the contour chart
		viewer.ImageMap = c.getHTMLImageMap("", "",
			"title='<*cdml*><*font=Arial Bold*>X={x|2}<*br*>Y={y|2}<*br*>Z={z|2}'")

		' Initializse the crosshair position to the center of the chart
		crossHairX = p.getLeftX() + p.getWidth() / 2
		crossHairY = p.getTopY() + p.getHeight() / 2

		' Draw the cross section And crosshair
		drawCrossSectionX(crossSectionViewerX)
		drawCrossSectionY(crossSectionViewerY)
		drawCrossHair(viewer)

	End Sub

	'
	' Draw the x cross section chart
	'
	Private Sub drawCrossSectionX(viewer As WinChartViewer)

		' Get data of the vertical cross section data at the given x coordinate
		Dim mainChart As XYChart = winChartViewer1.Chart
		Dim p As PlotArea = mainChart.getPlotArea()
		Dim z() As Double = contourLayer.getCrossSection(crossHairX, p.getBottomY(), crossHairX,
				p.getTopY())

		' Create XYChat of the same height as the main chart. Align the plot area with that of the 
		' main chart.
		Dim c As XYChart = New XYChart(100, mainChart.getHeight())
		c.setPlotArea(10, p.getTopY(), c.getWidth() - 22, p.getHeight(), -1, -1, -1,
				c.dashLineColor(&HAF000000, Chart.DotLine), -1)

		' The vertical chart will have the x-axis vertical And y-axis horizontal. Synchroinze the
		' vertical axis (x-axis) with the y-axis of the main chart. Synchroinze the horizontal 
		' axis (y-axis) with the color axis.
		c.swapXY()
		c.xAxis().syncAxis(mainChart.yAxis())
		c.yAxis().syncScale(contourLayer.colorAxis())

		' The vertical axis (x-axis) does Not need labels as it Is aligned with the main chart y-axis.
		c.xAxis().setLabelStyle("normal", 8, Chart.Transparent)

		' Rotate the horizontal axis (y-axis) labels by 270 degrees
		c.yAxis().setLabelStyle("normal", 8, Chart.TextColor, 270)

		' Add an area layer using the cross section data And the color scale of the color axis.
		Dim scaleColor As Integer = c.yScaleColor(contourLayer.colorAxis().getColorScale())
		Dim layer As AreaLayer = c.addAreaLayer(z, scaleColor)
		layer.setBorderColor(Chart.SameAsMainColor)
		layer.setXData(mainChart.getYValue(p.getBottomY()), mainChart.getYValue(p.getTopY()))

		' Display the chart
		viewer.Chart = c
		viewer.updateDisplay()

	End Sub

	'
	' Draw the y cross section chart
	'
	Private Sub drawCrossSectionY(viewer As WinChartViewer)

		' Get the vertical horizontal section data at the given y coordinate
		Dim mainChart As XYChart = winChartViewer1.Chart
		Dim p As PlotArea = mainChart.getPlotArea()
		Dim z() As Double = contourLayer.getCrossSection(p.getLeftX(), crossHairY, p.getRightX(),
			crossHairY)

		' Create XYChat of the same width as the main chart. Align the plot area with that of the 
		' main chart.
		Dim c As XYChart = New XYChart(mainChart.getWidth(), 100)
		c.setPlotArea(p.getLeftX(), 10, p.getWidth(), c.getHeight() - 22, -1, -1, -1,
			c.dashLineColor(&HAF000000, Chart.DotLine), -1)

		' Synchroinze the x-axis with the x-axis of the main chart. Synchroinze the y-axis with the
		' color axis.
		c.xAxis().syncAxis(mainChart.xAxis())
		c.yAxis().syncScale(contourLayer.colorAxis())

		' The x-axis does Not need labels as it Is aligned with the main chart x-axis.
		c.xAxis().setLabelStyle("normal", 8, Chart.Transparent)

		' Add an area layer using the cross section data And the color scale of the color axis.
		Dim scaleColor As Integer = c.yScaleColor(contourLayer.colorAxis().getColorScale())
		Dim layer As AreaLayer = c.addAreaLayer(z, scaleColor)
		layer.setBorderColor(Chart.SameAsMainColor)
		layer.setXData(mainChart.getXValue(p.getLeftX()), mainChart.getXValue(p.getRightX()))

		' Display the chart
		viewer.Chart = c
		viewer.updateDisplay()

	End Sub

	'
	' Draw cross hair cursor with axis labels
	'
	Private Sub drawCrossHair(viewer As WinChartViewer)

		' Get the chart to draw the crosshair on.
		Dim c As XYChart = viewer.Chart

		' The crosshair will be drawn on the dynamic layer of the chart.
		Dim d As DrawArea = c.initDynamicLayer()

		' Add two lines across the plot area of the chart
		Dim p As PlotArea = c.getPlotArea()
		d.line(crossHairX, p.getTopY(), crossHairX, p.getBottomY(), &H0, 2)
		d.line(p.getLeftX(), crossHairY, p.getRightX(), crossHairY, &H0, 2)

		' Update the display
		viewer.updateDisplay()

	End Sub

	Private Sub winChartViewer1_MouseMovePlotArea(sender As Object, e As MouseEventArgs) _
		Handles winChartViewer1.MouseMovePlotArea

		Dim viewer As WinChartViewer = winChartViewer1
		Dim mouseX As Integer = viewer.ChartMouseX
		Dim mouseY As Integer = viewer.ChartMouseY

		' Check if mouse button Is down
		If (MouseButtons And MouseButtons.Left) <> 0 Then
			'
			' If the mouse Is near the crosshair while the mouse button Is pressed, then it Is drag
			' dragging the crosshair And we need to update the contour projection.
			'
			If isDragging = DragState.Vertical AndAlso crossHairX <> mouseX - dragOffset Then
				' Is dragging the vertical crosshair line
				crossHairX = viewer.PlotAreaMouseX
				drawCrossSectionX(crossSectionViewerX)
				drawCrossHair(viewer)
			End If

			If isDragging = DragState.Horizontal AndAlso crossHairY <> mouseY - dragOffset Then
				' Is dragging the horizontal crosshair line
				crossHairY = viewer.PlotAreaMouseY
				drawCrossSectionY(crossSectionViewerY)
				drawCrossHair(viewer)
			End If
		Else
			'
			' If mouse Is near the crosshair, it can drag it by pressing the mouse button.
			'
			dragOffset = mouseX - crossHairX
			If Math.Abs(dragOffset) <= 8 Then
				isDragging = DragState.Vertical   ' Mouse Is a position to drag the vertical line
			Else
				dragOffset = mouseY - crossHairY
				If Math.Abs(dragOffset) <= 8 Then
					isDragging = DragState.Horizontal ' Mouse Is a position to drag the horizontal line
				Else
					isDragging = DragState.None
				End If
			End If
		End If
	End Sub

End Class