﻿Imports ChartDirector

Public Class FrmThreeDChartRotation

    ' The view angles
    Private m_elevationAngle As Double
    Private m_rotationAngle As Double

    ' Keep track of mouse drag
    Private m_lastMouseX As Integer
    Private m_lastMouseY As Integer
    Private m_isDragging As Boolean

    '
    ' Form Load event handler
    '
    Private Sub FrmThreeDChartRotation_Load(sender As Object, e As EventArgs) Handles MyBase.Load

        ' 3D view angles
        m_elevationAngle = 30
        m_rotationAngle = 45

        ' Keep track of mouse drag
        m_isDragging = False
        m_lastMouseX = -1
        m_lastMouseY = -1

        'Display the chart
        winChartViewer1.updateViewPort(True, False)

    End Sub

    '
    ' The ViewPortChanged event handler
    '
    Private Sub winChartViewer1_ViewPortChanged(sender As Object, e As ChartDirector.WinViewPortEventArgs) Handles winChartViewer1.ViewPortChanged

        ' Update the chart if necessary
        If e.NeedUpdateChart Then
            drawChart(winChartViewer1)
        End If
    End Sub

    Public Sub drawChart(viewer As WinChartViewer)

        ' The x And y coordinates of the grid
        Dim dataX As Double() = {-10, -9, -8, -7, -6, -5, -4, -3, -2, -1, 0, 1, 2, 3, 4, 5, 6, 7, 8,
            9, 10}
        Dim dataY As Double() = {-10, -9, -8, -7, -6, -5, -4, -3, -2, -1, 0, 1, 2, 3, 4, 5, 6, 7, 8,
            9, 10}

        ' The values at the grid points. In this example, we will compute the values using the
        ' formula z = x * sin(y) + y * sin(x).
        Dim dataZ(dataX.Length * dataY.Length - 1) As Double
        For yIndex As Integer = 0 To UBound(dataY)
            Dim y As Double = dataY(yIndex)
            For xIndex As Integer = 0 To UBound(dataX)
                Dim x As Double = dataX(xIndex)
                dataZ(yIndex * dataX.Length + xIndex) = x * Math.Sin(y) + y * Math.Sin(x)
            Next
        Next

        ' Create a SurfaceChart object of size 720 x 600 pixels
        Dim c As SurfaceChart = New SurfaceChart(720, 600)

        ' Set the center of the plot region at (330, 290), And set width x depth x height to
        ' 360 x 360 x 270 pixels
        c.setPlotRegion(330, 290, 360, 360, 270)

        ' Set the data to use to plot the chart
        c.setData(dataX, dataY, dataZ)

        ' Spline interpolate data to a 80 x 80 grid for a smooth surface
        c.setInterpolation(80, 80)

        ' Set the view angles
        c.setViewAngle(m_elevationAngle, m_rotationAngle)

        ' Check if draw frame only during rotation
        If m_isDragging And DrawFrameOnRotate.Checked Then
            c.setShadingMode(Chart.RectangularFrame)
        End If

        ' Add a color axis (the legend) in which the left center Is anchored at (660, 270). Set
        ' the length to 200 pixels And the labels on the right side.
        c.setColorAxis(650, 270, Chart.Left, 200, Chart.Right)

        ' Set the x, y And z axis titles using 10 points Arial Bold font
        c.xAxis().setTitle("X", "Arial Bold", 15) ';
        c.yAxis().setTitle("Y", "Arial Bold", 15) ';

        ' Set axis label font
        c.xAxis().setLabelStyle("Arial", 10)
        c.yAxis().setLabelStyle("Arial", 10)
        c.zAxis().setLabelStyle("Arial", 10)
        c.colorAxis().setLabelStyle("Arial", 10)

        ' Output the chart
        viewer.Chart = c

        'include tool tip for the chart
        viewer.ImageMap = c.getHTMLImageMap("", "",
            "title='<*cdml*>X: {x|2}<*br*>Y: {y|2}<*br*>Z: {z|2}'")

    End Sub

    Private Sub winChartViewer1_MouseMove(sender As Object, e As MouseEventArgs) Handles winChartViewer1.MouseMove

        Dim mouseX As Integer = winChartViewer1.ChartMouseX
        Dim mouseY As Integer = winChartViewer1.ChartMouseY

        ' Drag occurs if mouse button Is down And the mouse Is captured by the m_ChartViewer
        If (MouseButtons And MouseButtons.Left) <> 0 AndAlso winChartViewer1.Capture Then
            If m_isDragging Then

                ' The chart Is configured to rotate by 90 degrees when the mouse moves from 
                ' left to right, which Is the plot region width (360 pixels). Similarly, the
                ' elevation changes by 90 degrees when the mouse moves from top to buttom,
                ' which Is the plot region height (270 pixels).
                m_rotationAngle += (m_lastMouseX - mouseX) * 90.0 / 360
                m_elevationAngle += (mouseY - m_lastMouseY) * 90.0 / 270
                winChartViewer1.updateViewPort(True, False)
            End If

            ' Keep track of the last mouse position
            m_lastMouseX = mouseX
            m_lastMouseY = mouseY
            m_isDragging = True
        End If

    End Sub

    Private Sub winChartViewer1_MouseUp(sender As Object, e As MouseEventArgs) Handles winChartViewer1.MouseUp

        m_isDragging = False
        winChartViewer1.updateViewPort(True, False)

    End Sub

End Class
