Imports System
Imports Microsoft.VisualBasic
Imports ChartDirector

Public Class multileveltreemaplayout
    Implements DemoModule

    'Name of demo module
    Public Function getName() As String Implements DemoModule.getName
        Return "Multi Level Tree Map Layout"
    End Function

    'Number of charts produced in this demo module
    Public Function getNoOfCharts() As Integer Implements DemoModule.getNoOfCharts
        Return 6
    End Function

    'Main code for creating charts
    Public Sub createChart(viewer As WinChartViewer, chartIndex As Integer) _
        Implements DemoModule.createChart

        ' The first level nodes of the tree map. There are 4 nodes.
        Dim names() As String = {"A", "B", "C", "D"}

        ' Use random numbers for second level nodes
        Dim r As RanSeries = New RanSeries(11 + chartIndex)

        Dim series0() As Double = r.getSeries(6, 10, 100)
        Dim series1() As Double = r.getSeries(6, 10, 100)
        Dim series2() As Double = r.getSeries(6, 10, 100)
        Dim series3() As Double = r.getSeries(6, 10, 100)

        ' Colors for second level nodes
        Dim colors0() As Integer = {&Hddeedd, &Hbbeebb, &H99ee99, &H77ee77, &H55ee55, &H33ee33}
        Dim colors1() As Integer = {&Hffeedd, &Hffddbb, &Hffcc99, &Hffbb77, &Hffaa55, &Hff9933}
        Dim colors2() As Integer = {&Hddeeff, &Hbbddff, &H99ccee, &H77bbee, &H55aadd, &H3399dd}
        Dim colors3() As Integer = {&Hffeeff, &Heeccee, &Hddaadd, &Hcc88cc, &Hbb66bb, &Haa44aa}

        ' Create a Tree Map object of size 400 x 380 pixels
        Dim c As TreeMapChart = New TreeMapChart(400, 380)

        ' Set the plotarea at (10, 35) and of size 380 x 300 pixels
        c.setPlotArea(10, 35, 380, 300)

        ' Obtain the root of the tree map, which is the entire plot area
        Dim root As TreeMapNode = c.getRootNode()

        ' Add first level nodes to the root. We do not need to provide data as they will be computed
        ' as the sum of the second level nodes.
        root.setData(Nothing, names)

        ' Add second level nodes to each of the first level node
        root.getNode(0).setData(series0, Nothing, colors0)
        root.getNode(1).setData(series1, Nothing, colors1)
        root.getNode(2).setData(series2, Nothing, colors2)
        root.getNode(3).setData(series3, Nothing, colors2)

        ' Get the prototype (template) for the first level nodes.
        Dim nodeConfig As TreeMapNode = c.getLevelPrototype(1)

        ' Hide the first level node cell border by setting its color to transparent
        nodeConfig.setColors(-1, Chart.Transparent)

        ' Get the prototype (template) for the second level nodes.
        Dim nodeConfig2 As TreeMapNode = c.getLevelPrototype(2)

        ' Set the label format for the nodes to include the parent node's label and index of the
        ' second level node. Use semi-transparent black (3f000000) Arial Bold font and put the label
        ' at the center of the cell.
        nodeConfig2.setLabelFormat("{parent.label}{index}", "Arial Bold", 8, &H3f000000, _
            Chart.Center)

        ' Set the second level node cell border to white (ffffff)
        nodeConfig2.setColors(-1, &Hffffff)

        If chartIndex = 0 Then
            ' Squarify (default) - Layout the cells so that they are as square as possible.
            c.addTitle("Squarify", "Arial Bold", 15)
        ElseIf chartIndex = 1 Then
            ' Slice and Dice - First level cells flow horizontally. Second level cells flow
            ' vertically. (The setLayoutMethod also supports other flow directions.)
            c.addTitle("Slice and Dice", "Arial Bold", 15)
            root.setLayoutMethod(Chart.TreeMapSliceAndDice)
        ElseIf chartIndex = 2 Then
            ' Binary Split by Size - Split the cells into left/right groups so that their size are
            ' as close as possible. For each group, split the cells into top/bottom groups using the
            ' same criteria. Continue until each group contains one cell. (The setLayoutMethod also
            ' supports other flow directions.)
            c.addTitle("Binary Split by Size", "Arial Bold", 15)
            root.setLayoutMethod(Chart.TreeMapBinaryBySize)
            nodeConfig.setLayoutMethod(Chart.TreeMapBinaryBySize)
        ElseIf chartIndex = 3 Then
            ' Layout first level cells using Slice and Dice. Layout second level cells using Binary
            ' Split By Size.
            c.addTitle("Slice and Dice + Binary By Size", "Arial Bold", 15)
            root.setLayoutMethod(Chart.TreeMapSliceAndDice)
            nodeConfig.setLayoutMethod(Chart.TreeMapBinaryBySize)
        ElseIf chartIndex = 4 Then
            ' Layout first level cells using Slice and Dice. Layout second level cells using
            ' Squarify.
            c.addTitle("Slice and Dice + Squarify", "Arial Bold", 15)
            root.setLayoutMethod(Chart.TreeMapSliceAndDice)
            nodeConfig.setLayoutMethod(Chart.TreeMapSquarify)
        ElseIf chartIndex = 5 Then
            ' Layout first level cells using Binary Split By Size.. Layout second level cells using
            ' Strip. With Strip layout, cells flow from left to right, top to bottom. The number of
            ' cells in each row is such that they will be as close to a square as possible. (The
            ' setLayoutMethod also supports other flow directions.)
            c.addTitle("Binary Split By Size + Strip", "Arial Bold", 15)
            root.setLayoutMethod(Chart.TreeMapBinaryBySize)
            nodeConfig.setLayoutMethod(Chart.TreeMapStrip)
        End If

        ' Output the chart
        viewer.Chart = c

        'include tool tip for the chart
        viewer.ImageMap = c.getHTMLImageMap("clickable", "", _
            "title='<*cdml*>{parent.label}{index}: {value|2}'")

    End Sub

End Class

