Imports System
Imports Microsoft.VisualBasic
Imports ChartDirector

Public Class surface4d
    Implements DemoModule

    'Name of demo module
    Public Function getName() As String Implements DemoModule.getName
        Return "4D Surface Chart"
    End Function

    'Number of charts produced in this demo module
    Public Function getNoOfCharts() As Integer Implements DemoModule.getNoOfCharts
        Return 4
    End Function

    'Main code for creating charts
    Public Sub createChart(viewer As WinChartViewer, chartIndex As Integer) _
        Implements DemoModule.createChart

        ' The x and y coordinates of the grid
        Dim dataX() As Double = {-10, -9, -8, -7, -6, -5, -4, -3, -2, -1, 0, 1, 2, 3, 4, 5, 6, 7, _
            8, 9, 10}
        Dim dataY() As Double = {-10, -9, -8, -7, -6, -5, -4, -3, -2, -1, 0, 1, 2, 3, 4, 5, 6, 7, _
            8, 9, 10}

        ' The values at the grid points. In this example, we will compute the values using the
        ' formula z = x * sin(y) + y * sin(x).
        Dim dataZ((UBound(dataX) + 1) * (UBound(dataY) + 1) - 1) As Double
        For yIndex As Integer = 0 To UBound(dataY)
            Dim y As Double = dataY(yIndex)
            For xIndex As Integer = 0 To UBound(dataX)
                Dim x As Double = dataX(xIndex)
                dataZ(yIndex * (UBound(dataX) + 1) + xIndex) = x * Math.Sin(y) + y * Math.Sin(x)
            Next
        Next

        ' Create a SurfaceChart object of size 460 x 460 pixels, with white (ffffff) background and
        ' grey (888888) border.
        Dim c As SurfaceChart = New SurfaceChart(460, 460, &Hffffff, &H888888)

        ' Add a color axis at the top center of the chart, with labels at the bottom side
        Dim cAxis As ColorAxis = c.setColorAxis(c.getWidth() / 2, 10, Chart.Top, 250, Chart.Bottom)

        ' If the color is based on the z-values, the color axis will synchronize with the z-axis.
        ' (The Axis.syncAxis can be used to disable that.) Otherwise, the color axis will auto-scale
        ' independently. In the latter case, we set the tick spacing to at least 20 pixels.
        cAxis.setTickDensity(20)

        ' Set flat color axis style
        cAxis.setAxisBorder(Chart.Transparent, 0)

        If chartIndex = 0 Then
            ' The default is to use the Z values to determine the color.
            cAxis.setTitle("Color based on Z", "Arial Bold", 15)
            c.setData(dataX, dataY, dataZ)
        ElseIf chartIndex = 1 Then
            ' ChartDirector supports using an extra value (called W value) to determine the color.
            cAxis.setTitle("Color based on W", "Arial Bold", 15)

            ' Use random W values
            Dim r As RanSeries = New RanSeries(5)
            Dim dataW() As Double = r.get2DSeries(UBound(dataX) + 1, UBound(dataY) + 1, 0.5, 9.5)
            c.setData(dataX, dataY, dataZ, dataW)
        ElseIf chartIndex = 2 Then
            ' We can set the W values to the X coordinates. The color will then be determined by the
            ' X coordinates.
            cAxis.setTitle("Color based on X", "Arial Bold", 15)
            Dim colorX(UBound(dataZ)) As Double
            For yIndex As Integer = 0 To UBound(dataY)
                For xIndex As Integer = 0 To UBound(dataX)
                    colorX(yIndex * (UBound(dataX) + 1) + xIndex) = dataX(xIndex)
                Next
            Next
            c.setData(dataX, dataY, dataZ, colorX)
        Else
            ' We can set the W values to the Y coordinates. The color will then be determined by the
            ' Y coordinates.
            cAxis.setTitle("Color based on Y", "Arial Bold", 15)
            Dim colorY(UBound(dataZ)) As Double
            For yIndex As Integer = 0 To UBound(dataY)
                For xIndex As Integer = 0 To UBound(dataX)
                    colorY(yIndex * (UBound(dataX) + 1) + xIndex) = dataY(yIndex)
                Next
            Next
            c.setData(dataX, dataY, dataZ, colorY)
        End If

        ' Set the center of the plot region at (230, 250), and set width x depth x height to 240 x
        ' 240 x 170 pixels
        c.setPlotRegion(230, 250, 240, 240, 170)

        ' Set the plot region wall thichness to 3 pixels
        c.setWallThickness(3)

        ' Set the elevation and rotation angles to 45 degrees
        c.setViewAngle(45, 45)

        ' Set the perspective level to 20
        c.setPerspective(20)

        ' Spline interpolate data to a 50 x 50 grid for a smooth surface
        c.setInterpolation(50, 50)

        ' Add the axis titles
        c.xAxis().setTitle("X-Axis", "Arial Bold", 10)
        c.yAxis().setTitle("Y-Axis", "Arial Bold", 10)
        c.zAxis().setTitle("Z Axis", "Arial Bold", 10)

        ' Output the chart
        viewer.Chart = c

        ' Include tool tip for the chart
        If chartIndex = 1 Then
            viewer.ImageMap = c.getHTMLImageMap("clickable", "", _
                "title='<*cdml*>X: {x|2}<*br*>Y: {y|2}<*br*>Z: {z|2}<*br*>W: {w|2}'")
        Else
            viewer.ImageMap = c.getHTMLImageMap("clickable", "", _
                "title='<*cdml*>X: {x|2}<*br*>Y: {y|2}<*br*>Z: {z|2}'")
        End If

    End Sub

End Class

